@@ -50,6 +50,9 @@ class Cmd(object):
         parser.add_argument('--mailman-encoding',
                             help='encoding of the config.pck file',
                             default='UTF-8')
+        parser.add_argument('--force-private', action='store_const',
+                            const=True,
+                            help='all categories are created private regardless')
         parser.add_argument('--verbose', action='store_const',
                             const=True,
                             help='enable verbose logging')
