@@ -137,6 +137,10 @@ class DiscourseErrorUserActive(Exception):
     pass
 
 
+class DiscourseErrorUserTrustLevel(Exception):
+    pass
+
+
 class DiscourseErrorUserPreferences(Exception):
     pass
 
@@ -530,7 +534,7 @@ class Discourse(object):
 
     @staticmethod
     def user_fields():
-        return ('username', 'name', 'id', 'email', 'active')
+        return ('username', 'name', 'id', 'email', 'active', 'trust_level')
 
     def user_username_exists(self, username):
         try:
@@ -559,7 +563,7 @@ class Discourse(object):
         elif before is None:
             r = self.d._post('/users', **target)
             if r['success']:
-                return before, self.user_get(email)
+                after = self.user_get(email)
             else:
                 raise DiscourseErrorUserCreate(f'{target} failed {r["message"]}')
         else:
@@ -567,7 +571,9 @@ class Discourse(object):
             after = self.user_get(email)
             if after['active'] != target['active']:
                 _, after = self.user_active(email, target['active'])
-            return before, after
+        if 'trust_level' in target and after['trust_level'] != target['trust_level']:
+            _, after = self.user_trust_level(email, target['trust_level'])
+        return before, after
 
     def user_active(self, email, active):
         before = self.user_get(email)
@@ -590,10 +596,26 @@ class Discourse(object):
         else:
             raise DiscourseErrorUserActive(f'active={active} failed {r["message"]}')
 
-    def user_delete(self, email):
+    def user_trust_level(self, email, trust_level):
+        before = self.user_get(email)
+        if before['trust_level'] == trust_level:
+            return before, before
+        if self.args.dry_run:
+            after = copy.deepcopy(before)
+            after['trust_level'] = trust_level
+            return before, after
+        self.d._put(f'/admin/users/{before["id"]}/trust_level', level=trust_level)
+        after = self.user_get(email)
+        if after['trust_level'] != trust_level:
+            raise DiscourseErrorUserTrustLevel(
+                f'failed to change trust_level from {before["trust_level"]} to {trust_level}: '
+                f'it is now {after["trust_level"]}')
+        return before, after
+
+    def user_delete(self, email, **data):
         user = self.user_get(email)
         if user and not self.args.dry_run:
-            self.d._delete(f'/admin/users/{user["id"]}', delete_posts=True)
+            self.d._delete(f'/admin/users/{user["id"]}', delete_posts=True, **data)
         return user
 
     @staticmethod
@@ -718,3 +740,20 @@ class Discourse(object):
 
     def disconnect(self):
         del self.d
+
+    def emails_screened(self):
+        return self.d._get('/admin/logs/screened_emails.json')
+
+    def emails_allow(self, email):
+        for e in self.emails_screened():
+            if e["email"] == email:
+                self.d._delete(f'/admin/logs/screened_emails/{e["id"]}')
+                return True
+        return False
+
+    def emails_check(self, email):
+        try:
+            self.d._get(f'/u/check_email?email={email}')
+            return True
+        except DiscourseClientError:
+            return False
