@@ -66,6 +66,7 @@ class Importer(object):
             'username': username,
             'password': password,
             'active': 'true',
+            'trust_level': '1',
             'name': name})
 
     def users_add(self):
@@ -86,6 +87,19 @@ class Importer(object):
                 del self.mailman.user[email]
         return before, after
 
+    def users_ban(self):
+        before = set([s["email"] for s in self.discourse.emails_screened()])
+        after = copy.copy(before)
+        for email in self.mailman.info.get('ban_list', []):
+            if email in before:
+                continue
+            if self.discourse.emails_check(email) is False:
+                continue
+            self.user_create(email, '')
+            self.discourse.user_delete(email, block_email=True)
+            after.add(email)
+        return before, after
+
     def users_preferences(self, existing_users):
         before = {}
         after = {}
@@ -138,6 +152,12 @@ class Importer(object):
     def moderation_get(self):
         return self.mailman.info['moderation']
 
+    def archive_get(self):
+        if self.args.force_private:
+            return 'private'
+        else:
+            return self.mailman.info['archive']
+
     def category_settings(self):
         kwargs = {
             'email_in': self.email_get(),
@@ -145,7 +165,7 @@ class Importer(object):
 
         create_reply_see = Discourse.GROUP_PERMISSIONS_CREATE_REPLY_SEE
         see = Discourse.GROUP_PERMISSIONS_SEE
-        archive = self.mailman.info['archive']
+        archive = self.archive_get()
 
         if self.moderation_get() == 'no' and archive == 'public':
             kwargs.update({
@@ -297,6 +317,7 @@ class Importer(object):
                 self.name_get(), self.mailman.info['description'])
         logger.info('Adding users')
         (before['members'], after['members']) = self.users_add()
+        (before['banned'], after['banned']) = self.users_ban()
         logger.info('Populating the moderators group')
         (before['group-moderators'], _) = (
             self.discourse.group_create(self.group_moderators_name()))
@@ -309,7 +330,7 @@ class Importer(object):
         (_, after['group-moderators']) = self.discourse.group_create(
             self.group_moderators_name(), **self.group_moderators_settings())
 
-        if self.moderation_get() != 'no' or self.mailman.info['archive'] == 'private':
+        if self.moderation_get() != 'no' or self.archive_get() == 'private':
             logger.info('Populating the members group')
             (before['group-members'], _) = self.discourse.group_create(self.group_members_name())
             (before['group-members-list'],
