@@ -109,4 +109,9 @@ class Mailman(object):
                 logger.error(f'CONVERT usernames {usernames} for user {email} to an empty string')
                 usernames = ''
             self.user[email]['usernames'] = html.unescape(usernames)
+        if c.get('ban_list'):
+            self.info['ban_list'] = c['ban_list']
+            for email in c['ban_list']:
+                if email in self.user:
+                    del self.user[email]
         return True
