@@ -26,4 +26,5 @@ def test_options(version, tmpdir):
                               api_user='api',
                               url=url,
                               mailman_encoding='UTF-8',
-                              preserve_existing_user_preferences=False)
+                              preserve_existing_user_preferences=False,
+                              force_private=False)
