@@ -63,16 +63,15 @@ def test_users_add_invalid(test_options):
         i.discourse.user_delete(valid_email)
 
 
-@pytest.mark.parametrize("raw,cooked", [
-    ('Loïc Dachary', 'Loic_Dachary'),
-    ('  - / my name _.', 'my_name'),
-    ('__other name__', 'other_name'),
-    ('one__underscore', 'one_underscore'),
-    ('a hash is used if the name is too long', 'b58996c504c5638798eb'),
+@pytest.mark.parametrize("email,raw,cooked", [
+    ('user0@example.com', 'Loïc Dachary', 'Loic_Dachary'),
+    ('user1@example.com', '  - / my name _.', 'my_name'),
+    ('user2@example.com', '__other name__', 'other_name'),
+    ('user3@example.com', 'one__underscore', 'one_underscore'),
+    ('user4@example.com', 'a hash is used if the name is too long', '7e65550957227bd38fe2'),
 ])
-def test_users_add_normalize(test_options, raw, cooked):
+def test_users_add_normalize(test_options, email, raw, cooked):
     i = importer.Importer(test_options)
-    email = 'user@example.com'
     try:
         i.mailman.user = {
             email: {
@@ -206,6 +205,33 @@ def test_importer_moderation_no(test_options):
         cleanup()
 
 
+def test_importer_ban_list(test_options):
+    i = importer.Importer(test_options)
+
+    banned = 'banned0@example.com'
+    banned_similar = 'banned1@example.com'
+
+    def cleanup():
+        i.discourse.group_delete(i.group_moderators_name())
+        i.discourse.category_delete(i.name_get())
+        i.discourse.emails_allow(banned)
+    cleanup()
+    try:
+        c = i.mailman.load_pickle()
+        c['ban_list'] = [banned, banned_similar]
+        mailman_write_config(f'{test_options.mailman_config}', c)
+        i.mailman.load()
+
+        assert i.discourse.emails_screened() == []
+        before0, after0 = i.importer()
+        assert before0['banned'] == set()
+        assert after0['banned'] == set([banned])
+        assert i.discourse.emails_allow(banned) is True
+        assert i.discourse.emails_allow(banned) is False
+    finally:
+        cleanup()
+
+
 def test_importer_moderation_approval(test_options):
     i = importer.Importer(test_options)
     owner = 'owner@example.com'
@@ -460,6 +486,38 @@ def test_importer_category_settings(test_options, info, verify):
         i.discourse.user_delete(nonmember)
 
 
+def test_importer_category_settings_force_private(test_options):
+    i = importer.Importer(test_options)
+    i.args.force_private = True
+    member = 'member@example.com'
+    nonmember = 'nonmember@example.com'
+    try:
+        c = i.mailman.load_pickle()
+        mailman_add(c, member)
+        mailman_write_config(test_options.mailman_config, c)
+        i.mailman.load()
+        i.mailman.info.update({'archive': 'public'})
+
+        password = 'dashkeedfakojfiesMob'
+        username = 'NONMEMBERNAME'
+        _, _ = i.discourse.user_create(nonmember, **{
+            'active': 'true', 'username': username, 'password': password})
+
+        _, _ = i.importer()
+
+        assert user_cannot_see_category(i, nonmember)
+        title, topic_id = topic_post_ok(i, member)
+        assert topic_id == user_can_see_topic(i, member, title)
+
+    finally:
+        i.discourse.category_topics_delete(i.name_get())
+        i.discourse.category_delete(i.name_get())
+        i.discourse.group_delete(i.group_moderators_name())
+        i.discourse.group_delete(i.group_members_name())
+        i.discourse.user_delete(member)
+        i.discourse.user_delete(nonmember)
+
+
 def test_importer_notifications_level(test_options):
     i = importer.Importer(test_options)
     member = 'member@example.com'
