@@ -2,7 +2,7 @@ import argparse
 import html
 import pytest
 from mailman2discourse import mailman
-from tests.helpers_mailman import mailman_write_config, mailman_create_config
+from tests.helpers_mailman import mailman_write_config, mailman_create_config, mailman_add
 
 
 def test_load_synthetic(tmpdir):
@@ -16,6 +16,25 @@ def test_load_synthetic(tmpdir):
     assert 'private_roster' in m.info
 
 
+def test_ban_list(tmpdir):
+    n = 'listname'
+    c = mailman_create_config()
+    email = 'some@example.com'
+    mailman_add(c, email)
+    banned1 = 'banned1@example.com'
+    mailman_add(c, banned1)
+    banned2 = 'banned2@example.com'
+    c['ban_list'] = [banned1, banned2]
+    mailman_write_config(f'{tmpdir}/config.pck', c)
+    m = mailman.Mailman(argparse.Namespace(mailman_config=f'{tmpdir}/config.pck',
+                                           mailman_encoding='UTF-8',
+                                           list=n))
+    assert m.load() is True
+    assert banned1 not in m.user
+    assert banned1 in m.info['ban_list']
+    assert banned2 in m.info['ban_list']
+
+
 def test_load_skip(tmpdir, caplog):
     n = 'listname'
     c = mailman_create_config()
